@@ -49,10 +49,6 @@
 
 #include "tcpdump.h"
 
-#ifndef HAVE_STRLCPY
-#include "lib/strlcpy.h"
-#endif
-
 #ifdef DEBUG
 extern int debug;
 #endif
