@@ -362,7 +362,7 @@ typedef u_int32_t uint32_t
 */
 #ifdef UNUSED 
 #elif defined(__GNUC__) 
-# define UNUSED(x) UNUSED_ ## x __attribute__((unused)) 
+# define UNUSED(x) x __attribute__((unused))
 #elif defined(__LCLINT__) 
 # define UNUSED(x) /*@unused@*/ x 
 #else 
