@@ -10,8 +10,8 @@
 #define PKT_H
 
 #include "config.h"
+#include "lib/queue.h"
 #include "defines.h"
-#include "../../lib/queue.h"
 #include <sys/time.h>
 
 #ifdef HAVE_LIBDNET
