@@ -2,7 +2,7 @@
 
 /*
  *   Copyright (c) 2001-2010 Aaron Turner <aturner at synfin dot net>
- *   Copyright (c) 2013-2017 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
+ *   Copyright (c) 2013-2018 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
  *
  *   The Tcpreplay Suite of tools is free software: you can redistribute it 
  *   and/or modify it under the terms of the GNU General Public License as 
@@ -31,16 +31,15 @@
 
 
 /**
- * returns 0 for sucess w/o errors
- * returns 1 for sucess w/ warnings
+ * returns 0 for success w/o errors
+ * returns 1 for success w/ warnings
  * returns -1 for error
  */
 int 
 tcpedit_post_args(tcpedit_t *tcpedit) {
     int rcode = 0;
     int i;
-    long ttl;
-    uint32_t seed = 1;
+    uint32_t seed = 1, rand_num;
 
     assert(tcpedit);
 
@@ -50,7 +49,7 @@ tcpedit_post_args(tcpedit_t *tcpedit) {
         char **list = (char**)STACKLST_OPT(PNAT);
         int first = 1;
 
-        tcpedit->rewrite_ip ++;
+        tcpedit->rewrite_ip = true;
 
         do {
             char *p = *list++;
@@ -74,7 +73,7 @@ tcpedit_post_args(tcpedit_t *tcpedit) {
     
     /* --srcipmap */
     if (HAVE_OPT(SRCIPMAP)) {
-        tcpedit->rewrite_ip ++;
+        tcpedit->rewrite_ip = true;
         if (! parse_cidr_map(&tcpedit->srcipmap, OPT_ARG(SRCIPMAP))) {
             tcpedit_seterr(tcpedit, 
                 "Unable to parse --srcipmap=%s", OPT_ARG(SRCIPMAP));
@@ -84,7 +83,7 @@ tcpedit_post_args(tcpedit_t *tcpedit) {
 
     /* --dstipmap */
     if (HAVE_OPT(DSTIPMAP)) {
-        tcpedit->rewrite_ip ++;
+        tcpedit->rewrite_ip = true;
         if (! parse_cidr_map(&tcpedit->dstipmap, OPT_ARG(DSTIPMAP))) {
             tcpedit_seterr(tcpedit, 
                 "Unable to parse --dstipmap=%s", OPT_ARG(DSTIPMAP));
@@ -109,6 +108,8 @@ tcpedit_post_args(tcpedit_t *tcpedit) {
 
     /* --ttl */
     if (HAVE_OPT(TTL)) {
+        long ttl;
+
         if (strchr(OPT_ARG(TTL), '+')) {
             tcpedit->ttl_mode = TCPEDIT_TTL_MODE_ADD;            
         } else if (strchr(OPT_ARG(TTL), '-')) {
@@ -167,6 +168,16 @@ tcpedit_post_args(tcpedit_t *tcpedit) {
         }
     }
 
+    /* --rewrite-sequence */
+    if (HAVE_OPT(TCP_SEQUENCE)) {
+        tcpedit->tcp_sequence_enable = 1;
+        seed = OPT_VALUE_TCP_SEQUENCE;
+        for (i = 0; i < 5; ++i)
+            rand_num = tcpr_random(&seed);
+
+        tcpedit->tcp_sequence_adjust = rand_num;
+    }
+
     /* TCP/UDP port rewriting */
     if (HAVE_OPT(PORTMAP)) {
         int ct = STACKCT_OPT(PORTMAP);
@@ -213,11 +224,10 @@ tcpedit_post_args(tcpedit_t *tcpedit) {
         tcpedit->fuzz_factor = OPT_VALUE_FUZZ_FACTOR;
     }
 
-    for (i = 0; i < 5; ++i) {
-        seed = tcpr_random(&seed);
-    }
+    for (i = 0; i < 5; ++i)
+        rand_num = tcpr_random(&seed);
 
-    srandom(seed);
+    srandom(rand_num);
     if (HAVE_OPT(SEED)) {
         tcpedit->rewrite_ip = true;
         tcpedit->seed = seed;
@@ -238,28 +248,6 @@ tcpedit_post_args(tcpedit_t *tcpedit) {
         }
     }
 
-    /* 
-     * figure out the max packet len
-    if (tcpedit->l2.enabled) {
-        // custom l2 header
-        dbg(1, "Using custom L2 header to calculate max frame size\n");
-        tcpedit->maxpacket = tcpedit->mtu + tcpedit->l2.len;
-    }
-    else if (tcpedit->l2.dlt == DLT_EN10MB || tcpedit->l2.dlt == DLT_VLAN) {
-        // ethernet 
-        dbg(1, "Using Ethernet to calculate max frame size\n");
-        tcpedit->maxpacket = tcpedit->mtu + TCPR_ETH_H;
-    } else {
-         // uh, wtf is this now?  we'll just assume ethernet and hope things work
-        tcpedit->maxpacket = tcpedit->mtu + TCPR_ETH_H;
-        tcpedit_seterr(tcpedit, 
-            "Unsupported DLT type: %s.  We'll just treat it as ethernet.\n"
-            "You may need to increase the MTU (-t <size>) if you get errors\n",
-            pcap_datalink_val_to_name(tcpedit->l2.dlt));
-        rcode = 1;
-    }
-     */
-     
     /* parse the tcpedit dlt args */
     rcode = tcpedit_dlt_post_args(tcpedit);
     if (rcode < 0) {
