@@ -49,9 +49,6 @@
 #include "lib/tree.h"
 #include "tree.h"
 #include "lib/sll.h"
-#ifndef HAVE_STRLCPY
-#include "lib/strlcpy.h"
-#endif
 
 /*
  * global variables
