@@ -178,6 +178,11 @@ tcpreplay_post_args(tcpreplay_t *ctx, int argc)
         options->speed.speed = 0;
     } else if (HAVE_OPT(PPS)) {
         n = atof(OPT_ARG(PPS));
+        if (!n) {
+            tcpreplay_seterr(ctx, "invalid pps value '%s'", OPT_ARG(PPS));
+            ret = -1;
+            goto out;
+        }
         options->speed.speed = (COUNTER)(n * 60.0 * 60.0); /* convert to packets per hour */
         options->speed.mode = speed_packetrate;
         options->speed.pps_multi = OPT_VALUE_PPS_MULTI;
@@ -914,7 +919,7 @@ __tcpreplay_seterr(tcpreplay_t *ctx, const char *func,
         const int line, const char *file, const char *fmt, ...)
 {
     va_list ap;
-    char errormsg[TCPREPLAY_ERRSTR_LEN];
+    char errormsg[TCPREPLAY_ERRSTR_LEN - 32];
 
     assert(ctx);
     assert(file);
@@ -922,18 +927,16 @@ __tcpreplay_seterr(tcpreplay_t *ctx, const char *func,
     assert(line);
 
     va_start(ap, fmt);
-    if (fmt != NULL) {
-        (void)vsnprintf(errormsg,
-              (TCPREPLAY_ERRSTR_LEN - 1), fmt, ap);
-    }
+    if (fmt != NULL)
+        (void)vsnprintf(errormsg, sizeof(errormsg), fmt, ap);
 
     va_end(ap);
 
 #ifdef DEBUG
-    snprintf(ctx->errstr, (TCPREPLAY_ERRSTR_LEN -1), "From %s:%s() line %d:\n%s",
+    snprintf(ctx->errstr, sizeof(ctx->errstr), "From %s:%s() line %d:\n%s",
         file, func, line, errormsg);
 #else
-    snprintf(ctx->errstr, (TCPREPLAY_ERRSTR_LEN -1), "%s", errormsg);
+    snprintf(ctx->errstr, sizeof(ctx->errstr), "%s", errormsg);
 #endif
 }
 
@@ -951,7 +954,7 @@ tcpreplay_setwarn(tcpreplay_t *ctx, const char *fmt, ...)
 
     va_start(ap, fmt);
     if (fmt != NULL)
-        (void)vsnprintf(ctx->warnstr, (TCPREPLAY_ERRSTR_LEN - 1), fmt, ap);
+        (void)vsnprintf(ctx->warnstr, sizeof(ctx->warnstr), fmt, ap);
 
     va_end(ap);
 }
